==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_fil.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="1181"/>
        <source>None</source>
        <translation>Wala</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1460"/>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1469"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1901"/>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Naglalagda ang pag-record ng video. I-close ang window?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2034"/>
        <source>Switch Cameras</source>
        <translation>Magbago ng Camera</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2128"/>
        <source>Settings</source>
        <translation>Mga Setting</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Cancel</source>
        <translation>Iwan</translation>
    </message>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Close</source>
        <translation>I-close</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <location filename="../src/imageitem.cpp" line="66"/>
        <source>Copy</source>
        <translation>Kopyahin</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="70"/>
        <source>Delete</source>
        <translation>Tanggalin</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="74"/>
        <source>Open folder</source>
        <translation>Bumukas ng folder</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="77"/>
        <source>Print</source>
        <translation>Print</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="213"/>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="229"/>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Ang camera ay isang tool para mag-capture ng imahe at video gamit ang iyong PC camera o webcam.</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="16"/>
        <source>OptionPicLineEditBtn</source>
        <translation>Pamamaraan ng PicLineEditBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="17"/>
        <source>OptionVideoLineEditBtn</source>
        <translation>Pamamaraan ng VideoLineEditBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="18"/>
        <source>OptionFormatLabel</source>
        <translation>Pamamaraan ng FormatLabel</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="19"/>
        <source>OptionFrame</source>
        <translation>Pamamaraan ng Frame</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="20"/>
        <source>PicOption</source>
        <translation>PicOption</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="21"/>
        <source>VideoOption</source>
        <translation>VideoOption</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="22"/>
        <source>OptionPicSelectableLineEdit</source>
        <translation>Pamamaraan ng PicSelectableLineEdit</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="23"/>
        <source>OptionVideoSelectableLineEdit</source>
        <translation>Pamamaraan ng VideoSelectableLineEdit</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="24"/>
        <source>OptionInvalidDialog</source>
        <translation>Pamamaraan ng InvalidDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="25"/>
        <source>SettingDialog</source>
        <translation>SettingDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="27"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="28"/>
        <source>TitleBar</source>
        <translation>TitleBar</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="29"/>
        <source>TitleMenu</source>
        <translation>TitleMenu</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="30"/>
        <source>VideoPreviewWidget</source>
        <translation>VideoPreviewWidget</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="33"/>
        <source>SelectBtn</source>
        <translation>SelectBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="34"/>
        <source>PicVdBtn</source>
        <translation>PicVdBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="35"/>
        <source>TakeVdEndBtn</source>
        <translation>Bumanggit ng Vd EndBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="36"/>
        <source>ThumbnailPreview</source>
        <translation>Thumbnail Preview</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="37"/>
        <source>ModeSwitchBox</source>
        <translation>ModeSwitchBox</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="38"/>
        <source>SwitchRecordBtn</source>
        <translation>SwitchRecordBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="40"/>
        <source>LeftBtnsBox</source>
        <translation>LeftBtnsBox</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="41"/>
        <source>UnfoldBtn</source>
        <translation>UnfoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="42"/>
        <source>FoldBtn</source>
        <translation>FoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="43"/>
        <source>FlashlightUnfoldBtn</source>
        <translation>FlashlightUnfoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="44"/>
        <source>FlashlightFoldBtn</source>
        <translation>FlashlightFoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="45"/>
        <source>FlashlightOnBtn</source>
        <translation>FlashlightOnBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="46"/>
        <source>FlashlightOffBtn</source>
        <translation>FlashlightOffBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="47"/>
        <source>DelayUnfoldBtn</source>
        <translation>DelayUnfoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="48"/>
        <source>DelayFoldBtn</source>
        <translation>DelayFoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="49"/>
        <source>DelayNoDelayBtn</source>
        <translation>DelayNoDelayBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="50"/>
        <source>Delay3SecBtn</source>
        <translation>Delay3SecBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="51"/>
        <source>Delay6SecBtn</source>
        <translation>Delay6SecBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="52"/>
        <source>FiltersUnfoldBtn</source>
        <translation>FiltersUnfoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="53"/>
        <source>FiltersFoldBtn</source>
        <translation>FiltersFoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="54"/>
        <source>FiltersCloseBtn</source>
        <translation>FiltersCloseBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="55"/>
        <source>ExposureBtn</source>
        <translation>ExposureBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="56"/>
        <source>ExposureSlider</source>
        <translation>ExposureSlider</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="59"/>
        <source>ShortcutCallMenu</source>
        <translation>ShortcutCallMenu</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="60"/>
        <source>ShortcutCopy</source>
        <translation>ShortcutCopy</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="61"/>
        <source>ShortcutDelete</source>
        <translation>ShortcutDelete</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="62"/>
        <source>ShortcutOpenFolder</source>
        <translation>ShortcutOpenFolder</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="63"/>
        <source>ShortcutPrint</source>
        <translation>ShortcutPrint</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="66"/>
        <source>ViewShortCut</source>
        <translation>ViewShortCut</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="67"/>
        <source>SpaceShortCut</source>
        <translation>SpaceShortCut</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="70"/>
        <source>CloseDlg</source>
        <translation>CloseDlg</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="73"/>
        <source>PrintDialog</source>
        <translation>PrintDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="76"/>
        <source>CancelBtn</source>
        <translation>Iwan</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="77"/>
        <source>CloseBtn</source>
        <translation>Isara</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="287"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Wala kang pabor sa paggamit ng folder na ito</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="289"/>
        <source>Close</source>
        <translation>Isara</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="361"/>
        <source>Open folder</source>
        <translation>Bumuksan ang folder</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="909"/>
        <source>File not saved</source>
        <translation>Wala nang sinagot ang file</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="10"/>
        <source>Settings</source>
        <translation>Mga setting</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="11"/>
        <source>Basic</source>
        <translation>Pamamaraan</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="12"/>
        <source>File location</source>
        <translation>Lokasyon ng file</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="13"/>
        <source>Photos:</source>
        <translation>Mga larawan:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="14"/>
        <source>Videos:</source>
        <translation>Mga video:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="15"/>
        <source>Gridlines</source>
        <translation>Mga linya ng grid</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="16"/>
        <source>1*1 lines</source>
        <translation>1*1 linya</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="17"/>
        <source>2*2 lines</source>
        <translation>2*2 linya</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="18"/>
        <source>Shoot</source>
        <translation>Takpan</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="19"/>
        <source>Burst mode</source>
        <translation>Burst mode</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="20"/>
        <source>Self-timer delay</source>
        <translation>Pagkakasunod-sunod ng timer</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="21"/>
        <source>Mirror mode</source>
        <translation>Mirror mode</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="22"/>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="23"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="24"/>
        <source>Sound effects</source>
        <translation>Mga epekto ng tunog</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="25"/>
        <source>Output format</source>
        <translation>Format ng output</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="26"/>
        <source>Photo:</source>
        <translation>Larawan:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="27"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="28"/>
        <source>4 pcs</source>
        <translation>4 piraso</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="29"/>
        <source>10 pcs</source>
        <translation>10 piraso</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="30"/>
        <source>None</source>
        <translation>Wala</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="31"/>
        <source>Resolution settings</source>
        <translation>Mga setting ng resolusyon</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="32"/>
        <source>Maximum resolution:</source>
        <translation>Pinakamataas na resolusyon:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/shortcut.cpp" line="14"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="15"/>
        <source>Settings</source>
        <translation>Pangkatin</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="16"/>
        <source>Stop recording</source>
        <translation>Tigilin ang pag-record</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="17"/>
        <source>Stop taking photos</source>
        <translation>Tigilin ang pagkuha ng mga larawan</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="18"/>
        <source>Context menu</source>
        <translation>Menu ng konteksto</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="19"/>
        <source>Copy</source>
        <translation>Kopyahin</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="20"/>
        <source>Delete</source>
        <translation>Tanggalin</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="21"/>
        <source>Open</source>
        <translation>Bumuksan</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="22"/>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="23"/>
        <source>Help</source>
        <translation>Tulong</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="24"/>
        <source>Display shortcuts</source>
        <translation>Ipakita ang mga shortcut</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="191"/>
        <source>None</source>
        <translation>Wala</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="254"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="260"/>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="263"/>
        <source>Warm</source>
        <translation>Mapayapang</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="266"/>
        <source>Cold</source>
        <translation>Mapagod</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="269"/>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="272"/>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="275"/>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="278"/>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="83"/>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="90"/>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="97"/>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="112"/>
        <source>Delay capture</source>
        <translation>Delay capture</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="119"/>
        <source>None</source>
        <translation>Wala</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="142"/>
        <source>Filters</source>
        <translation>Filters</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="191"/>
        <source>Exposure</source>
        <translation>Exposure</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <location filename="../src/videowidget.cpp" line="346"/>
        <source>No webcam found</source>
        <translation>Walang webcam na nakita</translation>
    </message>
    <message>
        <location filename="../src/videowidget.cpp" line="384"/>
        <source>The webcam is in use</source>
        <translation>Ang webcam ay nasa paggamit</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.28.tar.xz: BUILD/src/translations/deepin-camera_fil.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fil">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Ang pag-record ng video ay nangyayari. I-close ang window?</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pamamaraan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Wala</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Palitan ang mga Camera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Iwanan</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>I-close</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopyahin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Tanggalin</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Bumuksan ang folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>I-print</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Wala kang pahintulot para mag-operate sa folder na ito</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>I-close</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Bumuksan ang folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pamamaraan</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Pamamaraan</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokasyon ng file</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Ilabas</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Burst mode</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Pang-ikot na delay</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format ng output</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Wala</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Camera ay isang utility para mag-capture ng imahe at video gamit ang iyong PC camera o webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>File ay hindi sinagot</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Paggawa ng resolusyon</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Mga larawan:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Mga video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Mga epekto ng tunog</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mood na salamin</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Lampara ng liwanag</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Mga linya ng grid</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 linya</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 linya</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Pinakamataas na resolusyon:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Mga setting</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Tigil ang pag-record</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyahin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Tanggalin</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Bumuksan</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Tulong</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Ipakita ang mga shortcut</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Tigil ang pagkuha ng mga larawan</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Mga menu ng konteksto</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Wala</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Warm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Cold</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Delay capture</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filters</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Exposure</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>No webcam found</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>The webcam is in use</translation>
    </message>
</context>
</TS>
